:tocdepth: 2

.. _examples:

Example usage
*************

Connect, and start and stop a recording
"""""""""""""""""""""""""""""""""""""""

.. literalinclude:: ../examples/basic.py
   :language: python
   :linenos:
   :emphasize-lines: 8,10,11,14

Print the estimated clock offset and current Pupil time
"""""""""""""""""""""""""""""""""""""""""""""""""""""""

.. literalinclude:: ../examples/estimated_clock_offset.py
   :language: python
   :linenos:
   :emphasize-lines: 10,11,14

Start the Annotation Plugin and send custom annotions
"""""""""""""""""""""""""""""""""""""""""""""""""""""

.. literalinclude:: ../examples/send_annotations.py
   :language: python
   :linenos:
   :emphasize-lines: 12,19,26-28,35-37
